<h1>CollapsibleFlatList</h1>
<p>A FlaList is collapsible,it can contain all data in the list,and re-render while data has change</p>

<h2>Installation</h2>

you can use yarn or npm

```
    npm install react-native-collapsibleflatlist
```

or

```
    yarn add react-native-collapsibleflatlist
```

<h2>Preview</h2>

![alt text](https://drive.google.com/uc?id=1WB2JgPfGfbgoscfG4dZl3wYjNhbv4h53 "Title")

<h2>Usage</h2>

<ul>
    <li>Simple Usage</li>
</ul>


```javascript
/**
 * @flow
 */

import React, { Component } from 'react';
import { StyleSheet, Text, View } from 'react-native';
import HiddenFlatlist from 'react-native-collapsibleflatlist';
import { textStyle } from 'src/utils/styles';

type Props = {};

export default class App extends Component<Props> {
  renderItem = ({ item }) => (
    <View style={{ flex: 1 }}>
      <Text style={textStyle.regular}>{item}</Text>
    </View>
  );

  render() {
    return (
      <View style={styles.container}>
        <View style={styles.innerContainer}>
          <HiddenFlatlist
            ref={ref => (this.list = ref)}
            data={['HaHa', '12312412', 'gwhwhdfns', 'hfndfnewr']}
            ListHeaderComponent={
              <View style={{ flex: 1, backgroundColor: '#fff' }}>
                <Text>Header</Text>
              </View>
            }
            keyExtractor={item => item}
            renderItem={this.renderItem}
            defaultValue={false}
            title={'HiddenList'}
            duration={3000}
            titleStyle={{
              backgroundColor: '#000034',
              borderTopWidth: 1,
              borderBottomWidth: 1,
              borderTopColor: '#fff',
              borderBottomColor: '#fff',
            }}
          />
        </View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#000034',
  },
  innerContainer: {
    marginTop: 64,
  },
});

```

<h2>Prop</h2>
<p>There is some Props can be available.</p>
<table>
    <tr>
        <th>Props</th>
        <th>Description</th>
        <th>Data Type</th>
        <th>Example</th>
    </tr>
    <tr>
        <td>data</td>
        <td>Data for the FlatList</td>
        <td>Array,[]</td>
        <td>['HaHa', '12312412', 'gwhwhdfns', 'hfndfnewr']</td>
    </tr>
    <tr>
        <td>keyExtractor</td>
        <td>keyExtractor for the FlatList</td>
        <td>function</td>
        <td>item=>item</td>
    </tr>
    <tr>
        <td>renderItem</td>
        <td>Takes an item from data and renders it into the list.</td>
        <td>function</td>
        <td></td>
    </tr>
    <tr>
        <td>defaultValue</td>
        <td>default of list is shown up or not.</td>
        <td>boolean</td>
        <td>true</td>
    </tr>
    <tr>
        <td>title</td>
        <td>title of Header</td>
        <td>String</td>
        <td>HiddenList</td>
    </tr>
    <tr>
        <td>titleStyle</td>
        <td>style of title</td>
        <td>style</td>
        <td></td>
    </tr>
    <tr>
        <td>titleTextStyle</td>
        <td>style of title text</td>
        <td>style</td>
        <td></td>
    </tr>
    <tr>
        <td>renderTitle</td>
        <td>render custom title</td>
        <td>ReactComponents</td>
        <td></td>
    </tr>
</table>

<h2>Function</h2>
<p>There is some function that can be used by ref.</p>
<table>
    <tr>
        <th>Function</th>
        <th>Description</th>
        <th>Example</th>
    </tr>
    <tr>
        <td>toggle</td>
        <td>toggle the list</td>
        <td>this.refs.list.toggle()</td>
    </tr>
</table>

<h2>About</h2>
<h3 style="font-weight: normal">Author:hank121314</h3>
<h3>Please let me know,if there is some feature which you want to add!</h3>
