import { Dimensions, PixelRatio } from 'react-native';

export const screenWidth = Dimensions.get('window').width;
export const screenHeight = Dimensions.get('window').height;

export const pixelRatio = PixelRatio.get();
export const pixelWidth = PixelRatio.getPixelSizeForLayoutSize(screenWidth);
export const pixelHeight = PixelRatio.getPixelSizeForLayoutSize(screenHeight);

export const hitSlop = { top: 10, bottom: 10, left: 10, right: 10 };

/**
 * Normalize value based on screen width
 * @param {number|string} bigger - value for bigger screen
 * @param {number|string} smaller - value for smaller screen
 */
export const normalize = (bigger, smaller) => (screenWidth > 320 ? bigger : smaller);

/**
 * 預設寬高以 iphone 6 為主
 */
export const defaults = {
  width: 375,
  height: 667,
};

/**
 * 依寬度縮放比例 (以 iphone 6 為主)
 */
export const scaleW = px => {
  if (px) {
    return Math.round(px * screenWidth / defaults.width);
  }
  return 0;
};

/**
 * 依高度縮放比例 (以 iphone 6 為主)
 */
export const scaleH = px => {
  if (px) {
    return Math.round(px * screenHeight / defaults.height);
  }
  return 0;
};

export const normalizeText = size => {
  // reference: https://github.com/react-native-training/react-native-elements/blob/master/src/helpers/normalizeText.js
  if (pixelRatio === 2) {
    // iphone 5s and older Androids
    if (screenWidth < 360) {
      return size * 0.95;
    }
    // iphone 5
    if (screenHeight < 667) {
      return size;
      // iphone 6-6s
    } else if (screenHeight >= 667 && screenHeight <= 735) {
      return size * 1.15;
    }
    // older phablets
    return size * 1.25;
  }
  if (pixelRatio === 3) {
    // catch Android font scaling on small machines
    // where pixel ratio / font scale ratio => 3:3
    if (screenWidth <= 360) {
      return size;
    }
    // Catch other weird android width sizings
    if (screenHeight < 667) {
      return size * 1.15;
      // catch in-between size Androids and scale font up
      // a tad but not too much
    }
    if (screenHeight >= 667 && screenHeight <= 735) {
      return size * 1.2;
    }
    // catch larger devices
    // ie iphone 6s plus / 7 plus / mi note 等等
    return size * 1.27;
  }
  if (pixelRatio === 3.5) {
    // catch Android font scaling on small machines
    // where pixel ratio / font scale ratio => 3:3
    if (screenWidth <= 360) {
      return size;
      // Catch other smaller android height sizings
    }
    if (screenHeight < 667) {
      return size * 1.2;
      // catch in-between size Androids and scale font up
      // a tad but not too much
    }
    if (screenHeight >= 667 && screenHeight <= 735) {
      return size * 1.25;
    }
    // catch larger phablet devices
    return size * 1.4;
  }
  // if older device ie pixelRatio !== 2 || 3 || 3.5
  return size;
};
